@@ -1,5 +1,7 @@
 # flake8: noqa
 import pkg_resources
+import sys
+import warnings
 
 from .config import config
 from .type_sys import type_system
@@ -16,6 +18,11 @@ from woodwork.accessor_utils import (
     is_schema_valid,
 )
 
+if sys.version_info.major == 3 and sys.version_info.minor == 7:  # pragma: no cover
+    warnings.warn(
+        "Woodwork may not support Python 3.7 in next non-bugfix release.", FutureWarning
+    )
+
 # Call functions registered by other libraries when woodwork is imported
 for entry_point in pkg_resources.iter_entry_points(
     "alteryx_open_src_initialize"
