@@ -3,11 +3,11 @@ from functools import wraps
 import numpy as np
 import pandas as pd
 
-from woodwork.exceptions import WoodworkNotInitError
+from woodwork.exceptions import ColumnNotPresentInSchemaError, WoodworkNotInitError
 from woodwork.utils import _get_column_logical_type, import_or_none
 
 dd = import_or_none("dask.dataframe")
-ks = import_or_none("databricks.koalas")
+ps = import_or_none("pyspark.pandas")
 
 
 def init_series(
@@ -24,7 +24,7 @@ def init_series(
     to match the dtype associated with the LogicalType.
 
     Args:
-        series (pd.Series, dd.Series, ks.Series, numpy.ndarray or pd.api.extensions.ExtensionArray):
+        series (pd.Series, dd.Series, ps.Series, numpy.ndarray or pd.api.extensions.ExtensionArray):
             The original series from which to create the Woodwork initialized series.
         logical_type (LogicalType or str, optional): The logical type that should be assigned
             to the series. If no value is provided, the LogicalType for the series will
@@ -75,7 +75,7 @@ def _is_series(data):
         return True
     elif _is_dask_series(data):
         return True
-    elif _is_koalas_series(data):
+    elif _is_spark_series(data):
         return True
     return False
 
@@ -85,7 +85,7 @@ def _is_dataframe(data):
         return True
     elif _is_dask_dataframe(data):
         return True
-    elif _is_koalas_dataframe(data):
+    elif _is_spark_dataframe(data):
         return True
     return False
 
@@ -127,13 +127,15 @@ def get_invalid_schema_message(dataframe, schema):
                 f"{df_dtype}, and {logical_types[name]} dtype, {valid_dtype}"
             )
     if schema.index is not None and isinstance(dataframe, pd.DataFrame):
-        # Index validation not performed for Dask/Koalas
+        # Index validation not performed for Dask/Spark
         if not pd.Series(dataframe.index, dtype=dataframe[schema.index].dtype).equals(
             pd.Series(dataframe[schema.index].values)
         ):
             return "Index mismatch between DataFrame and typing information"
         elif not dataframe[schema.index].is_unique:
             return "Index column is not unique"
+        elif dataframe[schema.index].isnull().any():
+            return "Index contains null values"
 
 
 def is_schema_valid(dataframe, schema):
@@ -165,14 +167,14 @@ def _is_dask_dataframe(data):
     return False
 
 
-def _is_koalas_dataframe(data):
-    if ks and isinstance(data, ks.DataFrame):
+def _is_spark_dataframe(data):
+    if ps and isinstance(data, ps.DataFrame):
         return True
     return False
 
 
-def _is_koalas_series(data):
-    if ks and isinstance(data, ks.Series):
+def _is_spark_series(data):
+    if ps and isinstance(data, ps.Series):
         return True
     return False
 
@@ -204,6 +206,11 @@ def _check_table_schema(method):
                 "calling DataFrame.ww.init"
             )
             raise WoodworkNotInitError(msg)
+        diff_cols = set(self._dataframe.columns).difference(
+            set(self._schema.columns.keys())
+        )
+        if diff_cols:
+            raise ColumnNotPresentInSchemaError(sorted(list(diff_cols)))
         return method(self, *args, **kwargs)
 
     return wrapper
