@@ -3,7 +3,7 @@ from inspect import isclass
 
 import woodwork as ww
 from woodwork.exceptions import DuplicateTagsWarning, StandardTagsChangedWarning
-from woodwork.logical_types import Boolean, BooleanNullable, Datetime
+from woodwork.logical_types import Boolean, BooleanNullable, Datetime, LatLong, Unknown
 from woodwork.utils import _convert_input_to_set
 
 
@@ -141,12 +141,22 @@ class ColumnSchema(object):
         """Whether the ColumnSchema is a Datetime column"""
         return type(self.logical_type) == Datetime
 
+    @property
+    def is_latlong(self):
+        """Whether the ColumnSchema is a LatLong column"""
+        return type(self.logical_type) == LatLong
+
     @property
     def is_boolean(self):
         """Whether the ColumnSchema is a Boolean column"""
         ltype_class = type(self.logical_type)
         return ltype_class == Boolean or ltype_class == BooleanNullable
 
+    @property
+    def is_unknown(self):
+        """Whether the ColumnSchema is a Unknown column"""
+        return type(self.logical_type) == Unknown
+
     def _add_semantic_tags(self, new_tags, name):
         """Add the specified semantic tags to the current set of tags
 
@@ -213,6 +223,14 @@ class ColumnSchema(object):
 
         self.semantic_tags = semantic_tags
 
+    @property
+    def custom_tags(self):
+        """The custom semantic tag(s) specified for the column."""
+        standard_tags = set()
+        if self.use_standard_tags:
+            standard_tags |= self.logical_type.standard_tags
+        return self.semantic_tags - standard_tags - {"index", "time_index"}
+
 
 def _validate_logical_type(logical_type):
     if type(logical_type) not in ww.type_system.registered_types:
