@@ -1,20 +1,27 @@
+import re
 import warnings
 
 import pandas as pd
-import pandas.api.types as pdtypes
+from pandas.api import types as pdtypes
 
-from woodwork.accessor_utils import _is_dask_series, _is_koalas_series
-from woodwork.exceptions import TypeConversionError, TypeConversionWarning
+from woodwork.accessor_utils import _is_dask_series, _is_spark_series
+from woodwork.config import config
+from woodwork.exceptions import (
+    TypeConversionError,
+    TypeConversionWarning,
+    TypeValidationError,
+)
 from woodwork.type_sys.utils import _get_specified_ltype_params
 from woodwork.utils import (
     _infer_datetime_format,
+    _is_valid_latlong_series,
     _reformat_to_latlong,
     camel_to_snake,
     import_or_none,
 )
 
 dd = import_or_none("dask.dataframe")
-ks = import_or_none("databricks.koalas")
+ps = import_or_none("pyspark.pandas")
 
 
 class ClassNameDescriptor(object):
@@ -48,7 +55,7 @@ class LogicalType(object, metaclass=LogicalTypeMetaClass):
     @classmethod
     def _get_valid_dtype(cls, series_type):
         """Return the dtype that is considered valid for a series with the given logical_type"""
-        if ks and series_type == ks.Series and cls.backup_dtype:
+        if ps and series_type == ps.Series and cls.backup_dtype:
             return cls.backup_dtype
         else:
             return cls.primary_dtype
@@ -64,6 +71,16 @@ class LogicalType(object, metaclass=LogicalTypeMetaClass):
                 raise TypeConversionError(series, new_dtype, type(self))
         return series
 
+    def validate(self, series, *args, **kwargs):
+        """Validates that a logical type is consistent with the series dtype. Performs additional type
+        specific validation, as required. When the series' dtype does not match the logical types' required dtype,
+        raises a TypeValidationError."""
+        valid_dtype = self._get_valid_dtype(type(series))
+        if valid_dtype != str(series.dtype):
+            raise TypeValidationError(
+                f"Series dtype '{series.dtype}' is incompatible with {self.type_string} dtype."
+            )
+
 
 class Address(LogicalType):
     """Represents Logical Types that contain address values.
@@ -92,6 +109,18 @@ class Age(LogicalType):
     primary_dtype = "int64"
     standard_tags = {"numeric"}
 
+    def validate(self, series, return_invalid_values=True):
+        """Validates age values by checking for non-negative values.
+
+        Args:
+            series (Series): Series of age values
+            return_invalid_values (bool): Whether or not to return invalid age values
+
+        Returns:
+            Series: If return_invalid_values is True, returns invalid age values.
+        """
+        return _validate_not_negative(series, return_invalid_values)
+
 
 class AgeFractional(LogicalType):
     """Represents Logical Types that contain non-negative floating point numbers indicating a person's age.
@@ -107,6 +136,18 @@ class AgeFractional(LogicalType):
     primary_dtype = "float64"
     standard_tags = {"numeric"}
 
+    def validate(self, series, return_invalid_values=True):
+        """Validates age values by checking for non-negative values.
+
+        Args:
+            series (Series): Series of age values
+            return_invalid_values (bool): Whether or not to return invalid age values
+
+        Returns:
+            Series: If return_invalid_values is True, returns invalid age values.
+        """
+        return _validate_not_negative(series, return_invalid_values)
+
 
 class AgeNullable(LogicalType):
     """Represents Logical Types that contain whole numbers indicating a person's age.
@@ -122,6 +163,18 @@ class AgeNullable(LogicalType):
     primary_dtype = "Int64"
     standard_tags = {"numeric"}
 
+    def validate(self, series, return_invalid_values=True):
+        """Validates age values by checking for non-negative values.
+
+        Args:
+            series (Series): Series of age values
+            return_invalid_values (bool): Whether or not to return invalid age values
+
+        Returns:
+            Series: If return_invalid_values is True, returns invalid age values.
+        """
+        return _validate_not_negative(series, return_invalid_values)
+
 
 class Boolean(LogicalType):
     """Represents Logical Types that contain binary values indicating true/false.
@@ -188,6 +241,21 @@ class CountryCode(LogicalType):
     standard_tags = {"category"}
 
 
+class CurrencyCode(LogicalType):
+    """Represents Logical Types that use the ISO-4217 internation standard currency code to represent currencies.
+
+    Examples:
+        .. code-block:: python
+
+            ["GBP", "JPY", "USD"]
+            ["SAR", "EUR", "CZK"]
+    """
+
+    primary_dtype = "category"
+    backup_dtype = "string"
+    standard_tags = {"category"}
+
+
 class Datetime(LogicalType):
     """Represents Logical Types that contain date and time information.
 
@@ -205,32 +273,46 @@ class Datetime(LogicalType):
     primary_dtype = "datetime64[ns]"
     datetime_format = None
 
-    def __init__(self, datetime_format=None):
+    def __init__(self, datetime_format=None, timezone=None):
         self.datetime_format = datetime_format
+        self.timezone = timezone
+
+    def _remove_timezone(self, series):
+        """Removes timezone from series and stores in logical type."""
+        if hasattr(series.dtype, "tz") and series.dtype.tz:
+            self.timezone = str(series.dtype.tz)
+            series = series.dt.tz_localize(None)
+        return series
 
     def transform(self, series):
         """Converts the series data to a formatted datetime. Datetime format will be inferred if datetime_format is None."""
         new_dtype = self._get_valid_dtype(type(series))
-        if new_dtype != str(series.dtype):
+        series = self._remove_timezone(series)
+        series_dtype = str(series.dtype)
+
+        if new_dtype != series_dtype:
             self.datetime_format = self.datetime_format or _infer_datetime_format(
                 series
             )
+            utc = self.datetime_format and self.datetime_format.endswith("%z")
             if _is_dask_series(series):
                 name = series.name
                 series = dd.to_datetime(
-                    series, format=self.datetime_format, errors="coerce"
+                    series, format=self.datetime_format, errors="coerce", utc=utc
                 )
                 series.name = name
-            elif _is_koalas_series(series):
-                series = ks.Series(
-                    ks.to_datetime(
+            elif _is_spark_series(series):
+                series = ps.Series(
+                    ps.to_datetime(
                         series.to_numpy(), format=self.datetime_format, errors="coerce"
                     ),
                     name=series.name,
                 )
             else:
                 try:
-                    series = pd.to_datetime(series, format=self.datetime_format)
+                    series = pd.to_datetime(
+                        series, format=self.datetime_format, utc=utc
+                    )
                 except (TypeError, ValueError):
                     warnings.warn(
                         f"Some rows in series '{series.name}' are incompatible with datetime format "
@@ -240,8 +322,13 @@ class Datetime(LogicalType):
                         TypeConversionWarning,
                     )
                     series = pd.to_datetime(
-                        series, format=self.datetime_format, errors="coerce"
+                        series,
+                        format=self.datetime_format,
+                        errors="coerce",
+                        utc=utc,
                     )
+
+        series = self._remove_timezone(series)
         return super().transform(series)
 
 
@@ -306,6 +393,18 @@ class EmailAddress(LogicalType):
 
     primary_dtype = "string"
 
+    def validate(self, series, return_invalid_values=False):
+        """Validates email address values based on the regex in the config.
+
+        Args:
+            series (Series): Series of email address values
+            return_invalid_values (bool): Whether or not to return invalid email address values
+
+        Returns:
+            Series: If return_invalid_values is True, returns invalid email address.
+        """
+        return _regex_validate("email_inference_regex", series, return_invalid_values)
+
 
 class Filepath(LogicalType):
     """Represents Logical Types that specify locations of directories and files
@@ -357,7 +456,7 @@ class LatLong(LogicalType):
 
     Note:
         LatLong values will be stored with the object dtype as a
-        tuple of floats (or a list of floats for Koalas DataFrames)
+        tuple of floats (or a list of floats for Spark DataFrames)
         and must contain only two values.
 
         Null latitude or longitude values will be stored as np.nan, and
@@ -375,22 +474,32 @@ class LatLong(LogicalType):
     primary_dtype = "object"
 
     def transform(self, series):
-        """Formats a series to be a tuple (or list for Koalas) of two floats."""
+        """Formats a series to be a tuple (or list for Spark) of two floats."""
         if _is_dask_series(series):
             name = series.name
             meta = (series, tuple([float, float]))
             series = series.apply(_reformat_to_latlong, meta=meta)
             series.name = name
-        elif _is_koalas_series(series):
+        elif _is_spark_series(series):
             formatted_series = series.to_pandas().apply(
-                _reformat_to_latlong, use_list=True
+                _reformat_to_latlong, is_spark=True
             )
-            series = ks.from_pandas(formatted_series)
+            series = ps.from_pandas(formatted_series)
         else:
             series = series.apply(_reformat_to_latlong)
 
         return super().transform(series)
 
+    def validate(self, series, return_invalid_values=False):
+        # TODO: we'll want to actually handle return_invalid_values in the ordinal and latlong logical types.
+        super().validate(series)
+        if not _is_valid_latlong_series(series):
+            raise TypeValidationError(
+                "Cannot initialize Woodwork. Series does not contain properly formatted "
+                "LatLong data. Try reformatting before initializing or use the "
+                "woodwork.init_series function to initialize."
+            )
+
 
 class NaturalLanguage(LogicalType):
     """Represents Logical Types that contain text or characters representing
@@ -445,7 +554,7 @@ class Ordinal(LogicalType):
     def __init__(self, order=None):
         self.order = order
 
-    def _validate_data(self, series):
+    def _validate_order_values(self, series):
         """Make sure order values are properly defined and confirm the supplied series
         does not contain any values that are not in the specified order values"""
         if self.order is None:
@@ -466,7 +575,7 @@ class Ordinal(LogicalType):
 
     def transform(self, series):
         """Validates the series and converts the dtype to match the logical type's if it is different."""
-        self._validate_data(series)
+        self._validate_order_values(series)
 
         typed_ser = super().transform(series)
         if pdtypes.is_categorical_dtype(typed_ser.dtype):
@@ -474,10 +583,18 @@ class Ordinal(LogicalType):
 
         return typed_ser
 
+    def validate(self, series, return_invalid_values=False):
+        # TODO: we'll want to actually handle return_invalid_values in the ordinal and latlong logical types.
+        super().validate(series)
+        self._validate_order_values(series)
+
+    def __str__(self):
+        return "{}: {}".format(self.__class__, self.order)
+
 
 class PhoneNumber(LogicalType):
     """Represents Logical Types that contain numeric digits and characters
-    representing a phone number
+    representing a phone number.
 
     Examples:
         .. code-block:: python
@@ -489,6 +606,19 @@ class PhoneNumber(LogicalType):
 
     primary_dtype = "string"
 
+    def validate(self, series, return_invalid_values=False):
+        """Validates PhoneNumber values based on the regex in the config.
+        By default, this validates US/Canada-based phone numbers.
+
+        Args:
+            series (Series): Series of phone number values.
+            return_invalid_values (bool): Whether or not to return invalid phone numbers.
+
+        Returns:
+            Series: If return_invalid_values is True, returns invalid phone numbers.
+        """
+        return _regex_validate("phone_inference_regex", series, return_invalid_values)
+
 
 class SubRegionCode(LogicalType):
     """Represents Logical Types that use the ISO-3166 standard sub-region code to
@@ -535,6 +665,18 @@ class URL(LogicalType):
 
     primary_dtype = "string"
 
+    def validate(self, series, return_invalid_values=False):
+        """Validates URL values based on the regex in the config.
+
+        Args:
+            series (Series): Series of URL values
+            return_invalid_values (bool): Whether or not to return invalid URLs
+
+        Returns:
+            Series: If return_invalid_values is True, returns invalid URLs.
+        """
+        return _regex_validate("url_inference_regex", series, return_invalid_values)
+
 
 class PostalCode(LogicalType):
     """Represents Logical Types that contain a series of postal codes for
@@ -545,13 +687,27 @@ class PostalCode(LogicalType):
 
             ["90210"
              "60018-0123",
-             "SW1A"]
+             "10010"]
     """
 
     primary_dtype = "category"
     backup_dtype = "string"
     standard_tags = {"category"}
 
+    def validate(self, series, return_invalid_values=False):
+        """Validates PostalCode values based on the regex in the config. Currently only validates US Postal codes.
+
+        Args:
+            series (Series): Series of PostalCode values.
+            return_invalid_values (bool): Whether or not to return invalid PostalCodes.
+
+        Returns:
+            Series: If return_invalid_values is True, returns invalid PostalCodes.
+        """
+        return _regex_validate(
+            "postal_code_inference_regex", series, return_invalid_values
+        )
+
 
 _NULLABLE_PHYSICAL_TYPES = {
     "boolean",
@@ -571,3 +727,55 @@ _NULLABLE_PHYSICAL_TYPES = {
     "string",
     "timedelta64[ns]",
 }
+
+
+def _regex_validate(regex_key, series, return_invalid_values):
+    """Validates data values based on the logical type regex in the config."""
+    regex = config.get_option(regex_key)
+
+    if _is_spark_series(series):
+
+        def match(x):
+            if isinstance(x, str):
+                return bool(re.match(regex, x))
+
+        invalid = series.apply(match).astype("boolean") == False  # noqa: E712
+
+    else:
+        invalid = ~series.str.match(regex).astype("boolean")
+
+    if return_invalid_values:
+        return series[invalid]
+
+    else:
+        any_invalid = invalid.any()
+        if dd and isinstance(any_invalid, dd.core.Scalar):
+            any_invalid = any_invalid.compute()
+
+        if any_invalid:
+            type_string = {
+                "url_inference_regex": "url",
+                "email_inference_regex": "email address",
+                "phone_inference_regex": "phone number",
+                "postal_code_inference_regex": "postal code",
+            }[regex_key]
+
+            info = f"Series {series.name} contains invalid {type_string} values. "
+            info += f"The {regex_key} can be changed in the config if needed."
+            raise TypeValidationError(info)
+
+
+def _validate_not_negative(series, return_invalid_values):
+    """Validates data values are non-negative."""
+    invalid = series.lt(0)
+    if return_invalid_values:
+        return series[invalid]
+
+    else:
+        any_invalid = invalid.any()
+        if dd and isinstance(any_invalid, dd.core.Scalar):
+            any_invalid = any_invalid.compute()
+
+        if any_invalid:
+            info = f"Series {series.name} contains negative values."
+            raise TypeValidationError(info)
