@@ -1,14 +1,14 @@
 import re
+from unittest.mock import patch
 
 import numpy as np
 import pandas as pd
 import pytest
-from mock import patch
 
 from woodwork.accessor_utils import (
     _is_dask_series,
     _is_dataframe,
-    _is_koalas_series,
+    _is_spark_series,
     init_series,
 )
 from woodwork.column_accessor import WoodworkColumnAccessor
@@ -16,12 +16,14 @@ from woodwork.column_schema import ColumnSchema
 from woodwork.exceptions import (
     ParametersIgnoredWarning,
     TypeConversionError,
+    TypeValidationError,
     TypingInfoMismatchWarning,
     WoodworkNotInitError,
 )
 from woodwork.logical_types import (
     Categorical,
     CountryCode,
+    CurrencyCode,
     Double,
     Integer,
     LatLong,
@@ -34,7 +36,7 @@ from woodwork.tests.testing_utils import is_property, is_public_method, to_panda
 from woodwork.utils import import_or_none
 
 dd = import_or_none("dask.dataframe")
-ks = import_or_none("databricks.koalas")
+ps = import_or_none("pyspark.pandas")
 
 
 def test_accessor_init(sample_series):
@@ -84,7 +86,7 @@ def test_accessor_init_with_schema_errors(sample_series):
     with pytest.raises(TypeError, match=error):
         head_series.ww.init(schema=int)
 
-    if _is_koalas_series(sample_series):
+    if _is_spark_series(sample_series):
         ltype_dtype = "string"
         new_dtype = "<U0"
     else:
@@ -147,7 +149,7 @@ def test_accessor_init_with_logical_type(sample_series):
 
 
 def test_accessor_init_with_invalid_logical_type(sample_series):
-    if _is_koalas_series(sample_series):
+    if _is_spark_series(sample_series):
         series_dtype = "<U0"
     else:
         series_dtype = "object"
@@ -158,7 +160,7 @@ def test_accessor_init_with_invalid_logical_type(sample_series):
         f"NaturalLanguage dtype. Try converting series dtype to '{correct_dtype}' before "
         "initializing or use the woodwork.init_series function to initialize."
     )
-    with pytest.raises(ValueError, match=error_message):
+    with pytest.raises(TypeValidationError, match=error_message):
         series.ww.init(logical_type=NaturalLanguage)
 
 
@@ -198,17 +200,15 @@ def test_error_accessing_methods_before_init(sample_series):
     method_args_dict = {
         "add_semantic_tags": [{"new_tag"}],
         "remove_semantic_tags": [{"new_tag"}],
-        "reset_semantic_tags": None,
         "set_logical_type": ["Integer"],
         "set_semantic_tags": [{"new_tag"}],
-        "box_plot_dict": [None],
     }
     error = (
         "Woodwork not initialized for this Series. Initialize by calling Series.ww.init"
     )
     for method in public_methods:
         func = getattr(sample_series.ww, method)
-        method_args = method_args_dict[method]
+        method_args = method_args_dict.get(method)
         with pytest.raises(WoodworkNotInitError, match=error):
             if method_args:
                 func(*method_args)
@@ -316,8 +316,8 @@ def test_origin_error_on_update(sample_series):
 
 def test_accessor_repr(sample_series):
     sample_series.ww.init(use_standard_tags=False)
-    # Koalas doesn't support categorical
-    if _is_koalas_series(sample_series):
+    # Spark doesn't support categorical
+    if _is_spark_series(sample_series):
         dtype = "string"
     else:
         dtype = "category"
@@ -363,6 +363,7 @@ def test_adds_category_standard_tag():
     logical_types = [
         Categorical,
         CountryCode,
+        CurrencyCode,
         Ordinal(order=(1, 2, 3)),
         PostalCode,
         SubRegionCode,
@@ -425,8 +426,8 @@ def test_set_logical_type_valid_dtype_change(sample_series):
 
     new_series = sample_series.ww.set_logical_type("NaturalLanguage")
 
-    if _is_koalas_series(sample_series):
-        # Koalas uses string dtype for Categorical
+    if _is_spark_series(sample_series):
+        # Spark uses string dtype for Categorical
         original_dtype = "string"
     else:
         original_dtype = "category"
@@ -443,9 +444,9 @@ def test_set_logical_type_invalid_dtype_change(sample_series):
         pytest.xfail(
             "Dask type conversion with astype does not fail until compute is called"
         )
-    if _is_koalas_series(sample_series):
+    if _is_spark_series(sample_series):
         pytest.xfail(
-            "Koalas allows this conversion, filling values it cannot convert with NaN "
+            "Spark allows this conversion, filling values it cannot convert with NaN "
             "and converting dtype to float."
         )
     sample_series.ww.init(logical_type="Categorical")
@@ -494,9 +495,9 @@ def test_series_methods_on_accessor_without_standard_tags(sample_series):
 
 
 def test_series_methods_on_accessor_returning_series_valid_schema(sample_series):
-    if _is_koalas_series(sample_series):
+    if _is_spark_series(sample_series):
         pytest.xfail(
-            "Running replace on Koalas series changes series dtype to object, invalidating schema"
+            "Running replace on Spark series changes series dtype to object, invalidating schema"
         )
     sample_series.ww.init()
 
@@ -543,8 +544,8 @@ def test_series_methods_on_accessor_inplace(sample_series):
 def test_series_methods_on_accessor_returning_series_invalid_schema(sample_series):
     sample_series.ww.init()
 
-    if _is_koalas_series(sample_series):
-        # Koalas uses `string` for Categorical, so must try a different conversion
+    if _is_spark_series(sample_series):
+        # Spark uses `string` for Categorical, so must try a different conversion
         original_type = "string"
         new_type = "Int64"
     else:
@@ -633,9 +634,9 @@ def test_ordinal_requires_instance_on_update(sample_series):
 
 
 def test_ordinal_with_order(sample_series):
-    if _is_koalas_series(sample_series) or _is_dask_series(sample_series):
+    if _is_spark_series(sample_series) or _is_dask_series(sample_series):
         pytest.xfail(
-            "Fails with Dask and Koalas - ordinal data validation not compatible"
+            "Fails with Dask and Spark - ordinal data validation not compatible"
         )
 
     series = sample_series.copy()
@@ -652,9 +653,9 @@ def test_ordinal_with_order(sample_series):
 
 
 def test_ordinal_with_incomplete_ranking(sample_series):
-    if _is_koalas_series(sample_series) or _is_dask_series(sample_series):
+    if _is_spark_series(sample_series) or _is_dask_series(sample_series):
         pytest.xfail(
-            "Fails with Dask and Koalas - ordinal data validation not supported"
+            "Fails with Dask and Spark - ordinal data validation not supported"
         )
 
     ordinal_incomplete_order = Ordinal(order=["a", "b"])
@@ -687,7 +688,7 @@ def test_latlong_init_error_with_invalid_series(latlongs):
         "LatLong data. Try reformatting before initializing or use the "
         "woodwork.init_series function to initialize."
     )
-    with pytest.raises(ValueError, match=error_message):
+    with pytest.raises(TypeValidationError, match=error_message):
         series.ww.init(logical_type="LatLong")
 
 
@@ -695,8 +696,8 @@ def test_latlong_formatting_with_init_series(latlongs):
     expected_series = pd.Series([(1.0, 2.0), (3.0, 4.0)])
     if _is_dask_series(latlongs[0]):
         expected_series = dd.from_pandas(expected_series, npartitions=2)
-    elif _is_koalas_series(latlongs[0]):
-        expected_series = ks.Series([[1.0, 2.0], [3.0, 4.0]])
+    elif _is_spark_series(latlongs[0]):
+        expected_series = ps.Series([[1.0, 2.0], [3.0, 4.0]])
 
     expected_series.ww.init(logical_type=LatLong)
     for series in latlongs:
@@ -761,7 +762,7 @@ def test_accessor_shallow_equality(sample_series):
     assert not metadata_col.ww.__eq__(diff_metadata_col.ww, deep=True)
 
     schema = metadata_col.ww.schema
-    diff_data_col = metadata_col.replace({"a": "1"})
+    diff_data_col = metadata_col.replace(to_replace="a", value="1")
     # dtype gets changed to object in replace
     diff_data_col = diff_data_col.astype("string")
 
@@ -858,19 +859,54 @@ def test_schema_property(sample_series):
     assert changed_schema != sample_series.ww._schema
 
 
-@patch("woodwork.column_accessor.WoodworkColumnAccessor._validate_logical_type")
-def test_validation_methods_called_init(mock_validate_logical_type, sample_series):
-    assert not mock_validate_logical_type.called
+@patch("woodwork.logical_types.LogicalType.validate")
+def test_validation_methods_called_init(mock_validate, sample_series):
+    assert not mock_validate.called
 
     not_validated = sample_series.copy()
     not_validated.ww.init(validate=False)
 
-    assert not mock_validate_logical_type.called
+    assert not mock_validate.called
 
     validated = sample_series.copy()
     validated.ww.init(validate=True)
 
-    assert mock_validate_logical_type.called
+    assert not mock_validate.called
+    assert validated.ww == not_validated.ww
+    pd.testing.assert_series_equal(to_pandas(validated), to_pandas(not_validated))
+
+
+@patch("woodwork.logical_types.LogicalType.validate")
+def test_ordinal_validation_methods_called_init(mock_validate, sample_series):
+    assert not mock_validate.called
+
+    not_validated = sample_series.copy()
+    not_validated.ww.init(logical_type=Ordinal(order=["a", "b", "c"]), validate=False)
+
+    assert not mock_validate.called
+
+    validated = sample_series.copy()
+    validated.ww.init(logical_type=Ordinal(order=["a", "b", "c"]), validate=True)
+
+    assert mock_validate.called
+    assert validated.ww == not_validated.ww
+    pd.testing.assert_series_equal(to_pandas(validated), to_pandas(not_validated))
+
+
+@patch("woodwork.logical_types.LogicalType.validate")
+def test_latlong_validation_methods_called_init(mock_validate, latlong_df_pandas):
+    assert not mock_validate.called
+
+    latlong_series = latlong_df_pandas["null_latitude"]
+    not_validated = latlong_series.copy()
+    not_validated.ww.init(LatLong, validate=False)
+
+    assert not mock_validate.called
+
+    validated = latlong_series.copy()
+    validated.ww.init(LatLong, validate=True)
+
+    assert mock_validate.called
     assert validated.ww == not_validated.ww
     pd.testing.assert_series_equal(to_pandas(validated), to_pandas(not_validated))
 
@@ -965,3 +1001,26 @@ def test_nullable_attribute(sample_df_pandas):
         expected = EXPECTED_COLUMN_NULLABILITIES[key]
 
         assert actual is expected
+
+
+def test_validate_logical_type(sample_df):
+    series = sample_df["email"]
+    series = init_series(series, logical_type="EmailAddress")
+    assert series.ww.validate_logical_type() is None
+
+    invalid_row = pd.Series({4: "bad_email"}, name="email", dtype="string")
+
+    if _is_spark_series(series):
+        invalid_row = ps.from_pandas(invalid_row)
+
+    series = series.append(invalid_row)
+    series = init_series(series, logical_type="EmailAddress")
+    match = "Series email contains invalid email address values. "
+    match += "The email_inference_regex can be changed in the config if needed."
+
+    with pytest.raises(TypeValidationError, match=match):
+        series.ww.validate_logical_type()
+
+    actual = series.ww.validate_logical_type(return_invalid_values=True)
+    expected = pd.Series({4: "bad_email"}, dtype="string")
+    assert to_pandas(actual).equals(expected)
