@@ -1,9 +1,9 @@
 import inspect
 import re
+from unittest.mock import patch
 
 import pandas as pd
 import pytest
-from mock import patch
 
 from woodwork import type_system
 from woodwork.exceptions import ColumnNotPresentError, DuplicateTagsWarning
@@ -305,7 +305,7 @@ def test_filter_schema_cols_include(sample_column_names, sample_inferred_logical
 
     filtered_log_type_string = schema._filter_cols(include="Unknown")
     filtered_log_type = schema._filter_cols(include=Unknown)
-    expected = {"full_name", "phone_number"}
+    expected = {"full_name"}
     assert filtered_log_type == filtered_log_type_string
     assert set(filtered_log_type) == expected
     expected = {"integer", "double", "double_with_nan", "age", "nullable_integer"}
@@ -353,6 +353,7 @@ def test_filter_schema_cols_exclude(sample_column_names, sample_inferred_logical
         "id",
         "url",
         "ip_address",
+        "phone_number",
     }
     assert filtered_log_type == filtered_log_type_string
     assert set(filtered_log_type) == expected
@@ -377,6 +378,7 @@ def test_filter_schema_cols_exclude(sample_column_names, sample_inferred_logical
         "id",
         "url",
         "ip_address",
+        "phone_number",
     }
     assert set(filtered_multiple_overlap) == expected
 
@@ -489,7 +491,7 @@ def test_filter_schema_non_string_cols():
 
 def test_get_subset_schema(sample_column_names, sample_inferred_logical_types):
     schema = TableSchema(sample_column_names, sample_inferred_logical_types)
-    new_schema = schema._get_subset_schema(sample_column_names[1:4])
+    new_schema = schema.get_subset_schema(sample_column_names[1:4])
     for col in new_schema.columns:
         assert new_schema.semantic_tags[col] == schema.semantic_tags[col]
         assert new_schema.logical_types[col] == schema.logical_types[col]
@@ -554,10 +556,10 @@ def test_set_logical_types(sample_column_names, sample_inferred_logical_types):
     assert schema.logical_types["phone_number"] == PhoneNumber
     assert schema.logical_types["age"] == Double
 
-    # Verify semantic tags were reset to standard tags in columns with Logical Type changes
-    assert schema.semantic_tags["full_name"] == {"category"}
-    assert schema.semantic_tags["email"] == set()
-    assert schema.semantic_tags["phone_number"] == set()
+    # Verify custom tags were not removed after changing logical types
+    assert schema.semantic_tags["full_name"] == {"category", "tag1"}
+    assert schema.semantic_tags["email"] == {"tag2"}
+    assert schema.semantic_tags["phone_number"] == {"tag3", "tag2"}
     assert schema.semantic_tags["age"] == {"numeric"}
 
     # Verify signup date column was unchanged
@@ -663,7 +665,7 @@ def test_set_types_combined(sample_column_names, sample_inferred_logical_types):
         retain_index_tags=False,
     )
 
-    assert schema.semantic_tags["id"] == {"numeric"}
+    assert schema.semantic_tags["id"] == {"numeric", "tag1"}
     assert schema.semantic_tags["age"] == {"numeric", "new_tag"}
 
     # don't use standard tags and lose index tags
@@ -688,7 +690,7 @@ def test_set_types_combined(sample_column_names, sample_inferred_logical_types):
     assert schema.semantic_tags["id"] == {"new_tag"}
     assert schema.semantic_tags["age"] == {"new_tag"}
     assert schema.semantic_tags["is_registered"] == {"new_tag"}
-    assert schema.semantic_tags["email"] == set()
+    assert schema.semantic_tags["email"] == {"tag2"}
     assert schema.semantic_tags["signup_date"] == {"time_index", "secondary_time_index"}
 
     assert schema.logical_types["id"] == Double
