@@ -1,9 +1,9 @@
-import importlib.resources as pkg_resources
+from importlib import resources as pkg_resources
 from typing import Any, Callable, Iterable, Union
 
 import numpy as np
 import pandas as pd
-import pandas.api.types as pdtypes
+from pandas.api import types as pdtypes
 
 import woodwork as ww
 from woodwork import data
@@ -117,6 +117,7 @@ class InferWithRegex:
         self.get_regex = get_regex
 
     def __call__(self, series: pd.Series) -> bool:
+        series = series.dropna()
         regex = self.get_regex()
 
         # Includes a check for object dtypes
@@ -133,12 +134,18 @@ class InferWithRegex:
             return False
         matches = series_match_method(pat=regex)
 
-        return matches.sum() == matches.count()
+        return matches.sum() == len(matches)
 
 
 email_address_func = InferWithRegex(
     lambda: ww.config.get_option("email_inference_regex")
 )
+phone_number_func = InferWithRegex(
+    lambda: ww.config.get_option("phone_inference_regex")
+)
+postal_code_func = InferWithRegex(
+    lambda: ww.config.get_option("postal_code_inference_regex")
+)
 url_func = InferWithRegex(lambda: ww.config.get_option("url_inference_regex"))
 ip_address_func = InferWithRegex(
     lambda: (
