@@ -5,12 +5,12 @@ import pandas as pd
 from woodwork.utils import import_or_none
 
 dd = import_or_none("dask.dataframe")
-ks = import_or_none("databricks.koalas")
+ps = import_or_none("pyspark.pandas")
 
 ColumnName = Hashable
 UseStandardTagsDict = Dict[ColumnName, bool]
 AnyDataFrame = pd.DataFrame
 if dd:
     AnyDataFrame = Union[AnyDataFrame, dd.DataFrame]
-if ks:
-    AnyDataFrame = Union[AnyDataFrame, ks.DataFrame]
+if ps:
+    AnyDataFrame = Union[AnyDataFrame, ps.DataFrame]
